@@ -1,8 +1,10 @@
 class BadRequest(Exception):
 
-    def __init__(self, message='Bad Request'):
+    def __init__(self, message='Bad Request', field=None):
         super(BadRequest, self).__init__(message)
         self.code = 400
+        if field:
+            self.field = field
 
 
 class Unauthorized(Exception):
@@ -21,9 +23,11 @@ class Forbidden(Exception):
 
 class NotFound(Exception):
 
-    def __init__(self, message='Resource Not Found'):
+    def __init__(self, message='Resource Not Found', field=None):
         super(NotFound, self).__init__(message)
         self.code = 404
+        if field:
+            self.field = field
 
 
 class ServerError(Exception):
